/* This is the widget wich draws the outcome of the precision test.
 * For this, it tests whether three points lie on a line or if
 * they make a left or right turn.
 * 
 * author: Lukas Novosad - novosluk@fel.cvut.cz
 * date: 28/9/2010
 *
 */

#ifndef ORIENTATIONWIDGET_H
#define ORIENTATIONWIDGET_H

// Qt includes
#include <QWidget>
#include <QPainter>
#include <QPaintEvent>
#include "ui_orientationwidget.h"

// CGAL includes
#include <CGAL/Homogeneous.h>
#include <CGAL/Cartesian.h>
#include <CGAL/Point_2.h>
#include <CGAL/predicates_on_points_2.h>

// some typdefs to make CGAL code more readable
typedef CGAL::Cartesian<float>			Rep_cart_float;
typedef CGAL::Cartesian<double>			Rep_cart_double;
typedef CGAL::Point_2<Rep_cart_float>   Point_CF;
typedef CGAL::Point_2<Rep_cart_double>  Point_CD;
// TODO: add typedefs for the additional point types

// the different kinds of precision so far:
// CF: cartesian float
// CD: cartesian double
// TODO: add the types defined above in order to use them in the switch statement
//       in the OrientationWidget::pointEvent
enum Precision {CF,CD};

class OrientationWidget : public QWidget
{
	Q_OBJECT

public:
	OrientationWidget(QWidget *parent = 0);
	~OrientationWidget();

    int getEpsilonExponent();

public slots:
	void setEpsilonExponent(int value);
	void setPrecision(Precision value);

protected:

	void paintEvent(QPaintEvent *);

private:
	Ui::OrientationWidgetClass ui;

	// the exponent for the epsilon value
	int _epsilonExponent;
	// the precision used for the test
	Precision _precision;

};

#endif // ORIENTATIONWIDGET_H